#include "dockwidget.h"

DockWidget::DockWidget(GLWidget * glw)
{

    m_ecostslider = new QSlider;
    m_ecostslider->setOrientation(Qt::Horizontal);
    m_ecostslider->setRange(0, 1000);

    m_ecostlabel = new QLabel;

    m_blendslider = new QSlider;
    m_blendslider->setOrientation(Qt::Horizontal);
    m_blendslider->setRange(0, 100);

    m_blendlabel = new QLabel;

    m_pointerrslider = new QSlider;
    m_pointerrslider->setOrientation(Qt::Horizontal);
    m_pointerrslider->setRange(0, 100);

    m_pointerrlabel = new QLabel;

    m_drawpolybox = new QCheckBox(QString("Draw Polyline"));
    m_drawcurvebox = new QCheckBox(QString("Draw French Curves"));
    m_greedybox = new QCheckBox(QString("Greedy Algorithm"));

    QVBoxLayout * layout = new QVBoxLayout;
    QWidget * widget = new QWidget;

    layout->setDirection(QBoxLayout::TopToBottom);

    layout->addWidget(m_ecostlabel);
    layout->addWidget(m_ecostslider);

    layout->addWidget(m_blendlabel);
    layout->addWidget(m_blendslider);

    layout->addWidget(m_pointerrlabel);
    layout->addWidget(m_pointerrslider);

    layout->addWidget(m_drawpolybox);
    layout->addWidget(m_drawcurvebox);

    layout->addWidget(m_greedybox);

    layout->addStretch();

    widget->setLayout(layout);

    setWidget(widget);

    connect(m_ecostslider, SIGNAL(valueChanged(int)), glw, SLOT(ChangedECost(int)));
    connect(m_ecostslider, SIGNAL(valueChanged(int)), this, SLOT(UpdateECostLabel(int)));

    connect(m_blendslider, SIGNAL(valueChanged(int)), glw, SLOT(ChangedBlendWin(int)));
    connect(m_blendslider, SIGNAL(valueChanged(int)), this, SLOT(UpdateBlendWinLabel(int)));

    connect(m_pointerrslider, SIGNAL(valueChanged(int)), glw, SLOT(ChangedPointError(int)));
    connect(m_pointerrslider, SIGNAL(valueChanged(int)), this, SLOT(UpdatePointErrorLabel(int)));

    connect(m_drawpolybox, SIGNAL(toggled(bool)), glw, SLOT(SetDrawPolyLine(bool)));
    connect(m_drawcurvebox, SIGNAL(toggled(bool)), glw, SLOT(SetDrawFrenchCurves(bool)));
    connect(m_greedybox, SIGNAL(toggled(bool)), glw, SLOT(SetDoGreedy(bool)));


    m_ecostslider->setValue(20);
    m_blendslider->setValue(15);
    m_pointerrslider->setValue(15);
    m_drawpolybox->setChecked(true);
    m_drawcurvebox->setChecked(true);

}

void DockWidget::UpdateECostLabel(int val)
{

    m_ecostlabel->setText(QString("Ecost: ") + QString::number(float(val) / 100.0f));
    update();

}

void DockWidget::UpdateBlendWinLabel(int val)
{
    m_blendlabel->setText(QString("Blend radius: ") + QString::number(val));
    update();        
}

void DockWidget::UpdatePointErrorLabel(int val)
{
    m_pointerrlabel->setText(QString("Point error: ") + QString::number(val));
    update();
}
